@@ -18,7 +18,7 @@ versionChanged() {
 }
 
 main() {
-    export KUBEVIRT_PROVIDER='k8s-1.19'
+    export KUBEVIRT_PROVIDER='k8s-1.21'
 
     source automation/check-patch.setup.sh
     cd ${TMP_PROJECT_PATH}
@@ -30,7 +30,7 @@ main() {
         export E2E_TEST_TIMEOUT=4h
     else
         # Don't run all upgrade tests in regular PRs, stick to those released under HCO
-        export RELEASES_SELECTOR="{0.39.3,0.44.3,0.47.0,0.48.0,0.49.0,99.0.0}"
+        export RELEASES_SELECTOR="{0.44.3,0.47.0,0.48.0,0.49.0,99.0.0}"
     fi
 
     make cluster-down
