@@ -24,3 +24,15 @@ sed -i "s/Version: \"99.0.0\",/Version: \"${released_version}\",/" test/releases
 
 echo 'Bump versions in Makefile'
 sed -i "s/VERSION_REPLACES ?= .*/VERSION_REPLACES ?= ${released_version}/" Makefile
+
+echo 'Prepare release notes'
+cat << EOF > version/description
+$released_version
+
+$commits
+
+EOF
+
+#echo 'Commit updates'
+#git checkout -b release-$released_version
+#git commit -a -s -m "Release $released_version"
