@@ -39,9 +39,11 @@ import (
 	"github.com/kubevirt/cluster-network-addons-operator/pkg/apply"
 	"github.com/kubevirt/cluster-network-addons-operator/pkg/controller/statusmanager"
 	"github.com/kubevirt/cluster-network-addons-operator/pkg/eventemitter"
+	"github.com/kubevirt/cluster-network-addons-operator/pkg/monitoring"
 	"github.com/kubevirt/cluster-network-addons-operator/pkg/names"
 	"github.com/kubevirt/cluster-network-addons-operator/pkg/network"
 	"github.com/kubevirt/cluster-network-addons-operator/pkg/util/k8s"
+	osconfv1 "github.com/openshift/api/config/v1"
 )
 
 // ManifestPath is the path to the manifest templates
@@ -210,6 +212,14 @@ func (r *ReconcileNetworkAddonsConfig) Reconcile(request reconcile.Request) (rec
 	}
 	r.clusterInfo.NmstateOperator = nmstateOperator
 
+	if r.clusterInfo.OpenShift4 {
+		isSingleReplica, err := isOpenshiftSingleReplica(r.client)
+		if err != nil {
+			log.Printf("failed to check if running on a singleReplica infrastrcuture: %v", err)
+		}
+		r.clusterInfo.IsSingleReplica = isSingleReplica
+	}
+
 	// Fetch the NetworkAddonsConfig instance
 	networkAddonsConfigStorageVersion := &cnaov1.NetworkAddonsConfig{}
 	err = r.client.Get(context.TODO(), request.NamespacedName, networkAddonsConfigStorageVersion)
@@ -220,6 +230,10 @@ func (r *ReconcileNetworkAddonsConfig) Reconcile(request reconcile.Request) (rec
 			// TODO: This can be dropped once we implement a finalizer waiting for all components to be removed
 			r.stopTrackingObjects()
 
+			if r.clusterInfo.MonitoringAvailable {
+				monitoring.ResetMonitoredComponents()
+			}
+
 			// Owned objects are automatically garbage collected. Return and don't requeue
 			return reconcile.Result{}, nil
 		}
@@ -308,6 +322,10 @@ func (r *ReconcileNetworkAddonsConfig) Reconcile(request reconcile.Request) (rec
 	// perform this check manually.
 	r.statusManager.SetFromPods()
 
+	if r.clusterInfo.MonitoringAvailable {
+		monitoring.TrackMonitoredComponents(&networkAddonsConfig.Spec, r.statusManager)
+	}
+
 	// Kubernetes sometimes fails to apply objects while we remove and recreate
 	// components, despite reporting success. In order to self-heal after these
 	// incidents, keep requeing.
@@ -512,20 +530,17 @@ func updateObjectsLabels(crLables map[string]string, objs []*unstructured.Unstru
 		// Label objects with version of the operator they were created by
 		labels[cnaov1.SchemeGroupVersion.Group+"/version"] = operatorVersionLabel
 		labels[names.PROMETHEUS_LABEL_KEY] = names.PROMETHEUS_LABEL_VALUE
-		err = updateObjectTemplateLabels(obj, labels, []string{names.PROMETHEUS_LABEL_KEY})
-		if err != nil {
-			return err
-		}
-
-		appLabelKeys := []string{names.COMPONENT_LABEL_KEY, names.PART_OF_LABEL_KEY, names.VERSION_LABEL_KEY, names.MANAGED_BY_LABEL_KEY}
+		labels[names.MANAGED_BY_LABEL_KEY] = names.MANAGED_BY_LABEL_DEFAULT_VALUE
 
+		appLabelKeys := []string{names.COMPONENT_LABEL_KEY, names.PART_OF_LABEL_KEY, names.VERSION_LABEL_KEY}
 		labels = updateLabelsFromCR(labels, crLables, appLabelKeys)
 		if err != nil {
 			return err
 		}
 		obj.SetLabels(labels)
 
-		err = updateObjectTemplateLabels(obj, labels, appLabelKeys)
+		templateLabelKeys := append(appLabelKeys, names.PROMETHEUS_LABEL_KEY, names.MANAGED_BY_LABEL_KEY)
+		err = updateObjectTemplateLabels(obj, labels, templateLabelKeys)
 		if err != nil {
 			return err
 		}
@@ -536,7 +551,6 @@ func updateObjectsLabels(crLables map[string]string, objs []*unstructured.Unstru
 
 func updateLabelsFromCR(labels, crLables map[string]string, appLabelKeys []string) map[string]string {
 	labels[names.COMPONENT_LABEL_KEY] = names.COMPONENT_LABEL_DEFAULT_VALUE
-	labels[names.MANAGED_BY_LABEL_KEY] = names.MANAGED_BY_LABEL_DEFAULT_VALUE
 	for _, key := range appLabelKeys {
 		if value, exist := crLables[key]; exist == true {
 			labels[key] = value
@@ -546,10 +560,10 @@ func updateLabelsFromCR(labels, crLables map[string]string, appLabelKeys []strin
 	return labels
 }
 
-func updateObjectTemplateLabels(obj *unstructured.Unstructured, labels map[string]string, appLabelKeys []string) error {
+func updateObjectTemplateLabels(obj *unstructured.Unstructured, labels map[string]string, templateLabelKeys []string) error {
 	kind := obj.GetKind()
 	if kind == "DaemonSet" || kind == "ReplicaSet" || kind == "Deployment" || kind == "StatefulSet" {
-		for _, key := range appLabelKeys {
+		for _, key := range templateLabelKeys {
 			if value, exist := labels[key]; exist == true {
 				err := unstructured.SetNestedField(obj.Object, value, "spec", "template", "metadata", "labels", key)
 				if err != nil {
@@ -683,3 +697,12 @@ func unstructuredToDeployment(obj *unstructured.Unstructured) (*appsv1.Deploymen
 	}
 	return deployment, nil
 }
+
+func isOpenshiftSingleReplica(c k8sclient.Client) (bool, error) {
+	infraConfig := &osconfv1.Infrastructure{}
+	if err := c.Get(context.TODO(), types.NamespacedName{Name: "cluster"}, infraConfig); err != nil {
+		return false, err
+	}
+
+	return infraConfig.Status.InfrastructureTopology == osconfv1.SingleReplicaTopologyMode, nil
+}
