@@ -21,7 +21,6 @@ import (
 	cnao "github.com/kubevirt/cluster-network-addons-operator/pkg/apis/networkaddonsoperator/shared"
 	cnaov1 "github.com/kubevirt/cluster-network-addons-operator/pkg/apis/networkaddonsoperator/v1"
 	eventemitter "github.com/kubevirt/cluster-network-addons-operator/pkg/eventemitter"
-	"github.com/kubevirt/cluster-network-addons-operator/pkg/monitoring"
 )
 
 const (
@@ -82,7 +81,6 @@ func (status *StatusManager) Set(reachedAvailableLevel bool, conditions ...condi
 	for i := 0; i < conditionsUpdateRetries; i++ {
 		err := status.set(reachedAvailableLevel, conditions...)
 		if err == nil {
-			monitoring.SetReadyGauge(reachedAvailableLevel)
 			log.Print("Successfully updated status conditions")
 			return
 		}
