@@ -27,7 +27,6 @@ import (
 	"github.com/kubevirt/cluster-network-addons-operator/pkg/network"
 	. "github.com/kubevirt/cluster-network-addons-operator/test/check"
 	"github.com/kubevirt/cluster-network-addons-operator/test/kubectl"
-	. "github.com/kubevirt/cluster-network-addons-operator/test/okd"
 	. "github.com/kubevirt/cluster-network-addons-operator/test/operations"
 )
 
@@ -281,25 +280,63 @@ var _ = Describe("NetworkAddonsConfig", func() {
 			CreateConfig(gvk, configSpec)
 			CheckConfigCondition(gvk, ConditionAvailable, ConditionTrue, 15*time.Minute, 30*time.Second)
 		})
-		Context("and checking CNAO prometheus endpoint", func() {
-			var err error
-			var scrapedData string
-			BeforeEach(func() {
-				scrapedData, err = GetScrapedDataFromMonitoringEndpoint()
-				Expect(err).ToNot(HaveOccurred())
-			})
-			It("Should report the expected metrics", func() {
-				expectedMetricValueMap := map[string]string{
-					"kubevirt_cnao_cr_ready": "1",
-				}
+	})
+	Context("when deploying components and checking CNAO prometheus endpoint", func() {
+		type prometheusScrapeParams struct {
+			configSpec             cnao.NetworkAddonsConfigSpec
+			expectedMetricValueMap map[string]string
+		}
+		DescribeTable("and checking scraped data",
+			func(p prometheusScrapeParams) {
+				By("deploying the configured NetworkAddonsConfigSpec")
+				CreateConfig(gvk, p.configSpec)
+				CheckConfigCondition(gvk, ConditionAvailable, ConditionTrue, 15*time.Minute, CheckDoNotRepeat)
 
-				for metricName, expectedValue := range expectedMetricValueMap {
-					metricEntry := FindMetric(scrapedData, metricName)
-					Expect(metricEntry).ToNot(BeEmpty(), fmt.Sprintf("metric %s does not appear in endpoint scrape", metricName))
-					Expect(metricEntry).To(Equal(fmt.Sprintf("%s %s", metricName, expectedValue)), fmt.Sprintf("metric %s does not have the expected value %s", metricName, expectedValue))
-				}
-			})
-		})
+				Eventually(func() error {
+					By("scraping the monitoring endpoint")
+					scrapedData, err := GetScrapedDataFromMonitoringEndpoint()
+					Expect(err).ToNot(HaveOccurred())
+
+					By("comparing the scraped Data to the expected metrics' values")
+					for metricName, expectedValue := range p.expectedMetricValueMap {
+						metricEntry := FindMetric(scrapedData, metricName)
+						Expect(metricEntry).ToNot(BeEmpty(), fmt.Sprintf("metric %s does not appear in endpoint scrape", metricName))
+
+						if metricEntry != fmt.Sprintf("%s %s", metricName, expectedValue) {
+							return fmt.Errorf("metric %s does not have the expected value %s", metricName, expectedValue)
+						}
+					}
+					return nil
+				}, 3*time.Minute, time.Minute).Should(Succeed(), "Should scrape the correct metrics")
+			},
+			Entry("should report the expected metrics when deploying all components", prometheusScrapeParams{
+				configSpec: cnao.NetworkAddonsConfigSpec{
+					LinuxBridge: &cnao.LinuxBridge{},
+					Multus:      &cnao.Multus{},
+					NMState:     &cnao.NMState{},
+					KubeMacPool: &cnao.KubeMacPool{},
+					Ovs:         &cnao.Ovs{},
+					MacvtapCni:  &cnao.MacvtapCni{},
+				},
+				expectedMetricValueMap: map[string]string{
+					"kubevirt_cnao_cr_ready":                "1",
+					"kubevirt_cnao_cr_kubemacpool_deployed": "1",
+				},
+			}),
+			Entry("should report the expected metrics when deploying all components but kubemacpool", prometheusScrapeParams{
+				configSpec: cnao.NetworkAddonsConfigSpec{
+					LinuxBridge: &cnao.LinuxBridge{},
+					Multus:      &cnao.Multus{},
+					NMState:     &cnao.NMState{},
+					Ovs:         &cnao.Ovs{},
+					MacvtapCni:  &cnao.MacvtapCni{},
+				},
+				expectedMetricValueMap: map[string]string{
+					"kubevirt_cnao_cr_ready":                "1",
+					"kubevirt_cnao_cr_kubemacpool_deployed": "0",
+				},
+			}),
+		)
 	})
 	//2178
 	Context("when kubeMacPool is deployed", func() {
@@ -530,12 +567,7 @@ func checkConfigChange(gvk schema.GroupVersionKind, components []Component, whil
 		while()
 	}()
 
-	// On OpenShift 4, Multus is already deployed by default
-	onlyMultusOnOKDCluster := (len(components) == 1 &&
-		IsOnOKDCluster() &&
-		components[0].ComponentName == MultusComponent.ComponentName)
-	noComponentToDeploy := len(components) == 0 || onlyMultusOnOKDCluster
-	if noComponentToDeploy {
+	if len(components) == 0 {
 		// Wait until Available condition is reported. Should be fast when no components are
 		// being deployed
 		CheckConfigCondition(gvk, ConditionAvailable, ConditionTrue, 5*time.Minute, CheckDoNotRepeat)
